==> App-Dochazka-WWW-0.146.tar.gz: App-Dochazka-WWW-0.146/share/js/dochazka-www/drowselect-init.js <==
// ************************************************************************* 
// Copyright (c) 2014-2016, SUSE LLC
// 
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
// 
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
// 
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
// 
// 3. Neither the name of SUSE LLC nor the names of its contributors may be
// used to endorse or promote products derived from this software without
// specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
// ************************************************************************* 
//
// app/drowselect-init.js
//
// Round one of drowselect initialization (called from app/target-init)
//
"use strict";

define ([
    'lib',
    'app/lib',
    'target'
], function (
    lib,
    dochazkaLib,
    target
) {

    var entries = dochazkaLib.entries;

    return function () {

        target.push('privHistoryDrowselect', {
            'name': 'privHistoryDrowselect',
            'type': 'drowselect',
            'menuText': 'Privilege (status) history',
            'title': 'Privilege (status) history',
            'preamble': null,
            'aclProfile': 'admin',
            'entries': [entries.pHeffective, entries.pHpriv],
            'hook': lib.holdObject,
            'miniMenu': {
                entries: ['privHistoryAddRecord', 'privHistoryDeleteAction'],
                back: ['Back', 'mainPriv']
            }
        });

        target.push('schedHistoryDrowselect', {
            'name': 'schedHistoryDrowselect',
            'type': 'drowselect',
            'menuText': 'Schedule history',
            'title': 'Schedule history',
            'preamble': null,
            'aclProfile': 'admin',
            'entries': [entries.pHeffective, entries.sDid, entries.sHid],
            'hook': lib.holdObject,
            'miniMenu': {
                entries: ['schedHistoryAddRecord', 'schedHistoryDeleteAction'],
                back: ['Back', 'mainSched']
            }
        });

    };
    
});

==> App-Dochazka-WWW-0.147.tar.gz: App-Dochazka-WWW-0.147/share/js/dochazka-www/drowselect-init.js <==
// ************************************************************************* 
// Copyright (c) 2014-2016, SUSE LLC
// 
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
// 
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
// 
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
// 
// 3. Neither the name of SUSE LLC nor the names of its contributors may be
// used to endorse or promote products derived from this software without
// specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
// ************************************************************************* 
//
// app/drowselect-init.js
//
// Round one of drowselect initialization (called from app/target-init)
//
"use strict";

define ([
    'lib',
    'app/lib',
    'target'
], function (
    lib,
    dochazkaLib,
    target
) {

    var entries = dochazkaLib.entries;

    return function () {

        target.push('privHistoryDrowselect', {
            'name': 'privHistoryDrowselect',
            'type': 'drowselect',
            'menuText': 'Privilege (status) history',
            'title': 'Privilege (status) history',
            'preamble': null,
            'aclProfile': 'admin',
            'entries': [entries.pHeffective, entries.pHpriv],
            'hook': lib.holdObject,
            'miniMenu': {
                entries: ['privHistoryAddRecord', 'privHistoryDeleteAction'],
                back: ['Back', 'actionPrivHistory']
            }
        });

        target.push('schedHistoryDrowselect', {
            'name': 'schedHistoryDrowselect',
            'type': 'drowselect',
            'menuText': 'Schedule history',
            'title': 'Schedule history',
            'preamble': null,
            'aclProfile': 'admin',
            'entries': [entries.pHeffective, entries.sDid, entries.sDcode],
            'hook': lib.holdObject,
            'miniMenu': {
                entries: ['schedHistoryAddRecord', 'schedHistoryDeleteAction'],
                back: ['Back', 'actionSchedHistory']
            }
        });

    };
    
});
